# IMP01 - Coding Standards

Quy chuẩn coding: style guides, naming conventions, clean code principles.

## Best Practices

| # | Best Practice | Mô tả |
|---|---------------|-------|
| BP01 | [Clean Code Principles](IMP01-BP01-Clean-Code-Principles.md) | Principles viết code sạch, dễ maintain |
| BP02 | [SOLID Principles](IMP01-BP02-SOLID-Principles.md) | 5 nguyên tắc thiết kế OOP |

## Tham khảo

- Clean Code by Robert C. Martin
- The Pragmatic Programmer
- Code Complete by Steve McConnell
